/**************************************
  Header file for auto hide functions
  (c) 1999 Daniel Serodio
  GnomeICU
***************************************/

#ifndef __AUTOHIDE_H__
#define __AUTOHIDE_H__

#include "common.h"

extern gint autohide_timeout_tag;
extern gboolean autohide_cbs_are_connected;

void start_autohide_timeout_cb( GtkWidget *widget );
void stop_autohide_timeout_cb( GtkWidget *widget );

#endif /* __AUTOHIDE_H__ */
